@@ -1,4 +1,5 @@
 """Test module for KeycloakOpenID."""
+
 from typing import Tuple
 from unittest import mock
 
@@ -186,7 +187,7 @@ def test_exchange_token(
     oid, username, password = oid_with_credentials
 
     # Allow impersonation
-    admin.realm_name = oid.realm_name
+    admin.change_current_realm(oid.realm_name)
     admin.assign_client_role(
         user_id=admin.get_user_id(username=username),
         client_id=admin.get_client_id(client_id="realm-management"),
@@ -208,9 +209,7 @@ def test_exchange_token(
 
     # Exchange token with the new user
     new_token = oid.exchange_token(
-        token=token["access_token"],
-        audience=oid.client_id,
-        subject=username,
+        token=token["access_token"], audience=oid.client_id, subject=username
     )
     assert oid.userinfo(token=new_token["access_token"]) == {
         "email": f"{username}@test.test",
